@@ -323,8 +323,13 @@ def db_version(ctx, module, show_all):
     metavar="VERSION",
     default=None,
 )
+@click.option(
+    "--interactive/--non-interactive",
+    help="Do not ask questions (use default answer to all questions)",
+    default=True,
+)
 @click.pass_context
-def db_upgrade(ctx, module, to_version):
+def db_upgrade(ctx, module, to_version, interactive):
     """Upgrade the database for given module (to a given version if specified).
 
     Examples::
@@ -360,7 +365,7 @@ def db_upgrade(ctx, module, to_version):
             fg="yellow",
             bold=True,
         )
-        if not click.confirm(
+        if interactive and not click.confirm(
             f"Write the module information ({module}) in the database?", default=True
         ):
             raise click.BadParameter("Migration aborted.")
@@ -389,13 +394,19 @@ def db_upgrade(ctx, module, to_version):
             f"{ds_version} of the datastore backend {db_module}"
         )
 
-    new_db_version = swh_db_upgrade(dbname, module, to_version)
-    click.secho(f"Migration to version {new_db_version} done", fg="green")
-    if new_db_version < ds_version:
+    if to_version == db_version:
         click.secho(
-            f"Warning: migration was not complete: the current version is {ds_version}",
-            fg="yellow",
+            f"No migration needed: the current version is {db_version}", fg="yellow",
         )
+    else:
+        new_db_version = swh_db_upgrade(dbname, module, to_version)
+        click.secho(f"Migration to version {new_db_version} done", fg="green")
+        if new_db_version < ds_version:
+            click.secho(
+                "Warning: migration was not complete: "
+                f"the current version is {ds_version}",
+                fg="yellow",
+            )
 
 
 def get_dburl_from_config(cfg):
